@@ -25,9 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: amazons3.py 1097 2015-01-05 20:43:36Z pronovic $
 # Purpose  : "Store" type extension that writes data to Amazon S3.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -57,7 +56,7 @@ and not root.
 You can optionally configure Cedar Backup to encrypt data before sending it
 to S3.  To do that, provide a complete command line using the C{${input}} and
 C{${output}} variables to represent the original input file and the encrypted
-output file.  This command will be executed as the backup user.  
+output file.  This command will be executed as the backup user.
 
 For instance, you can use something like this with GPG::
 
@@ -136,8 +135,8 @@ class AmazonS3Config(object):
    @sort: __init__, __repr__, __str__, __cmp__, warnMidnite, s3Bucket
    """
 
-   def __init__(self, warnMidnite=None, s3Bucket=None, encryptCommand=None, 
-               fullBackupSizeLimit=None, incrementalBackupSizeLimit=None):
+   def __init__(self, warnMidnite=None, s3Bucket=None, encryptCommand=None,
+                fullBackupSizeLimit=None, incrementalBackupSizeLimit=None):
       """
       Constructor for the C{AmazonS3Config} class.
 
@@ -303,9 +302,9 @@ class AmazonS3Config(object):
    warnMidnite = property(_getWarnMidnite, _setWarnMidnite, None, "Whether to generate warnings for crossing midnite.")
    s3Bucket = property(_getS3Bucket, _setS3Bucket, None, doc="Amazon S3 Bucket in which to store data")
    encryptCommand = property(_getEncryptCommand, _setEncryptCommand, None, doc="Command used to encrypt data before upload to S3")
-   fullBackupSizeLimit = property(_getFullBackupSizeLimit, _setFullBackupSizeLimit, None, 
+   fullBackupSizeLimit = property(_getFullBackupSizeLimit, _setFullBackupSizeLimit, None,
                                   doc="Maximum size of a full backup, in bytes")
-   incrementalBackupSizeLimit = property(_getIncrementalBackupSizeLimit, _setIncrementalBackupSizeLimit, None, 
+   incrementalBackupSizeLimit = property(_getIncrementalBackupSizeLimit, _setIncrementalBackupSizeLimit, None,
                                          doc="Maximum size of an incremental backup, in bytes")
 
 
@@ -349,7 +348,7 @@ class LocalConfig(object):
 
       @note: It is strongly suggested that the C{validate} option always be set
       to C{True} (the default) unless there is a specific need to read in
-      invalid configuration from disk.  
+      invalid configuration from disk.
 
       @param xmlData: XML data representing configuration.
       @type xmlData: String data.
@@ -485,7 +484,7 @@ class LocalConfig(object):
    def _parseAmazonS3(parent):
       """
       Parses an amazons3 configuration section.
-      
+
       We read the following individual fields::
 
          warnMidnite                 //cb_config/amazons3/warn_midnite
@@ -592,20 +591,20 @@ def _findCorrectDailyDir(options, config, local):
    tomorrowStoreInd = os.path.join(tomorrowPath, STORE_INDICATOR)
    if options.full:
       if os.path.isdir(todayPath) and os.path.exists(todayStageInd):
-         logger.info("Amazon S3 process will use current day's staging directory [%s]" % todayPath)
+         logger.info("Amazon S3 process will use current day's staging directory [%s]", todayPath)
          return { todayPath:todayDate }
       raise IOError("Unable to find staging directory to process (only tried today due to full option).")
    else:
       if os.path.isdir(todayPath) and os.path.exists(todayStageInd) and not os.path.exists(todayStoreInd):
-         logger.info("Amazon S3 process will use current day's staging directory [%s]" % todayPath)
+         logger.info("Amazon S3 process will use current day's staging directory [%s]", todayPath)
          return { todayPath:todayDate }
       elif os.path.isdir(yesterdayPath) and os.path.exists(yesterdayStageInd) and not os.path.exists(yesterdayStoreInd):
-         logger.info("Amazon S3 process will use previous day's staging directory [%s]" % yesterdayPath)
+         logger.info("Amazon S3 process will use previous day's staging directory [%s]", yesterdayPath)
          if local.amazons3.warnMidnite:
             logger.warn("Warning: Amazon S3 process crossed midnite boundary to find data.")
          return { yesterdayPath:yesterdayDate }
       elif os.path.isdir(tomorrowPath) and os.path.exists(tomorrowStageInd) and not os.path.exists(tomorrowStoreInd):
-         logger.info("Amazon S3 process will use next day's staging directory [%s]" % tomorrowPath)
+         logger.info("Amazon S3 process will use next day's staging directory [%s]", tomorrowPath)
          if local.amazons3.warnMidnite:
             logger.warn("Warning: Amazon S3 process crossed midnite boundary to find data.")
          return { tomorrowPath:tomorrowDate }
@@ -642,15 +641,15 @@ def _applySizeLimits(options, config, local, stagingDirs):
    if limit is None:
       logger.debug("No Amazon S3 size limit will be applied.")
    else:
-      logger.debug("Amazon S3 size limit is: %d bytes" % limit)
+      logger.debug("Amazon S3 size limit is: %d bytes", limit)
       contents = BackupFileList()
       for stagingDir in stagingDirs:
          contents.addDirContents(stagingDir)
       total = contents.totalSize()
-      logger.debug("Amazon S3 backup size is is: %d bytes" % total)
+      logger.debug("Amazon S3 backup size is is: %d bytes", total)
       if total > limit:
-         logger.error("Amazon S3 size limit exceeded: %.0f bytes > %d bytes" % (total, limit))
-         raise ValueError("Amazon S3 size limit exceeded: %.0f bytes > %d bytes" % (total, limit))
+         logger.error("Amazon S3 size limit exceeded: %.0f bytes > %d bytes", total, limit)
+         raise ValueError("Amazon S3 size limit exceeded: %.0f bytes > %d bytes", total, limit)
       else:
          logger.info("Total size does not exceed Amazon S3 size limit, so backup can continue.")
 
@@ -666,7 +665,7 @@ def _writeToAmazonS3(config, local, stagingDirs):
    Each of the staging directories listed in C{stagingDirs} will be written to
    the configured Amazon S3 bucket from local configuration.  The directories
    will be placed into the image at the root by date, so staging directory
-   C{/opt/stage/2005/02/10} will be placed into the S3 bucket at C{/2005/02/10}.  
+   C{/opt/stage/2005/02/10} will be placed into the S3 bucket at C{/2005/02/10}.
    If an encrypt commmand is provided, the files will be encrypted first.
 
    @param config: Config object.
@@ -677,10 +676,10 @@ def _writeToAmazonS3(config, local, stagingDirs):
    @raise IOError: If there is a problem writing to Amazon S3
    """
    for stagingDir in stagingDirs.keys():
-      logger.debug("Storing stage directory to Amazon S3 [%s]." % stagingDir)
+      logger.debug("Storing stage directory to Amazon S3 [%s].", stagingDir)
       dateSuffix = stagingDirs[stagingDir]
       s3BucketUrl = "s3://%s/%s" % (local.amazons3.s3Bucket, dateSuffix)
-      logger.debug("S3 bucket URL is [%s]" % s3BucketUrl)
+      logger.debug("S3 bucket URL is [%s]", s3BucketUrl)
       _clearExistingBackup(config, s3BucketUrl)
       if local.amazons3.encryptCommand is None:
          logger.debug("Encryption is disabled; files will be uploaded in cleartext.")
@@ -710,8 +709,8 @@ def _writeStoreIndicator(config, stagingDirs):
    @param stagingDirs: Dictionary mapping directory path to date suffix.
    """
    for stagingDir in stagingDirs.keys():
-      writeIndicatorFile(stagingDir, STORE_INDICATOR, 
-                         config.options.backupUser, 
+      writeIndicatorFile(stagingDir, STORE_INDICATOR,
+                         config.options.backupUser,
                          config.options.backupGroup)
 
 
@@ -731,7 +730,7 @@ def _clearExistingBackup(config, s3BucketUrl):
    result = executeCommand(suCommand, [config.options.backupUser, "-c", actualCommand])[0]
    if result != 0:
       raise IOError("Error [%d] calling AWS CLI to clear existing backup for [%s]." % (result, s3BucketUrl))
-   logger.debug("Completed clearing any existing backup in S3 for [%s]" % s3BucketUrl)
+   logger.debug("Completed clearing any existing backup in S3 for [%s]", s3BucketUrl)
 
 
 ###############################
@@ -751,7 +750,7 @@ def _uploadStagingDir(config, stagingDir, s3BucketUrl):
    result = executeCommand(suCommand, [config.options.backupUser, "-c", actualCommand])[0]
    if result != 0:
       raise IOError("Error [%d] calling AWS CLI to upload staging directory to [%s]." % (result, s3BucketUrl))
-   logger.debug("Completed uploading staging dir [%s] to [%s]" % (stagingDir, s3BucketUrl))
+   logger.debug("Completed uploading staging dir [%s] to [%s]", stagingDir, s3BucketUrl)
 
 
 ###########################
@@ -789,7 +788,7 @@ def _verifyUpload(config, stagingDir, s3BucketUrl):
          else:
             if size != contents[key]:
                raise IOError("File size differs [%s], expected %s bytes but got %s bytes" % (entry, size, contents[key]))
-   logger.debug("Completed verifying upload from [%s] to [%s]." % (stagingDir, s3BucketUrl))
+   logger.debug("Completed verifying upload from [%s] to [%s].", stagingDir, s3BucketUrl)
 
 
 ################################
@@ -820,5 +819,5 @@ def _encryptStagingDir(config, local, stagingDir, encryptedDir):
             result = executeCommand(suCommand, [config.options.backupUser, "-c", actualCommand])[0]
             if result != 0:
                raise IOError("Error [%d] encrypting [%s]." % (result, cleartext))
-   logger.debug("Completed encrypting staging directory [%s] into [%s]" % (stagingDir, encryptedDir))
+   logger.debug("Completed encrypting staging directory [%s] into [%s]", stagingDir, encryptedDir)
 
