@@ -25,9 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: split.py 1028 2013-03-21 14:33:51Z pronovic $
 # Purpose  : Provides an extension to split up large files in staging directories.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -229,7 +228,7 @@ class LocalConfig(object):
 
       @note: It is strongly suggested that the C{validate} option always be set
       to C{True} (the default) unless there is a specific need to read in
-      invalid configuration from disk.  
+      invalid configuration from disk.
 
       @param xmlData: XML data representing configuration.
       @type xmlData: String data.
@@ -362,7 +361,7 @@ class LocalConfig(object):
    def _parseSplit(parent):
       """
       Parses an split configuration section.
-      
+
       We read the following individual fields::
 
          sizeLimit      //cb_config/split/size_limit
@@ -412,7 +411,7 @@ def executeAction(configPath, options, config):
    local = LocalConfig(xmlPath=configPath)
    dailyDirs = findDailyDirs(config.stage.targetDir, SPLIT_INDICATOR)
    for dailyDir in dailyDirs:
-      _splitDailyDir(dailyDir, local.split.sizeLimit, local.split.splitSize, 
+      _splitDailyDir(dailyDir, local.split.sizeLimit, local.split.splitSize,
                      config.options.backupUser, config.options.backupGroup)
       writeIndicatorFile(dailyDir, SPLIT_INDICATOR, config.options.backupUser, config.options.backupGroup)
    logger.info("Executed the split extended action successfully.")
@@ -439,13 +438,13 @@ def _splitDailyDir(dailyDir, sizeLimit, splitSize, backupUser, backupGroup):
    @raise ValueError: If the encrypt mode is not supported.
    @raise ValueError: If the daily staging directory does not exist.
    """
-   logger.debug("Begin splitting contents of [%s]." % dailyDir)
+   logger.debug("Begin splitting contents of [%s].", dailyDir)
    fileList = getBackupFiles(dailyDir)  # ignores indicator files
    for path in fileList:
       size = float(os.stat(path).st_size)
       if size > sizeLimit.bytes:
          _splitFile(path, splitSize, backupUser, backupGroup, removeSource=True)
-   logger.debug("Completed splitting contents of [%s]." % dailyDir)
+   logger.debug("Completed splitting contents of [%s].", dailyDir)
 
 
 ########################
@@ -494,10 +493,10 @@ def _splitFile(sourcePath, splitSize, backupUser, backupGroup, removeSource=Fals
          changeOwnership(path, backupUser, backupGroup)
       if removeSource:
          if os.path.exists(sourcePath):
-            try: 
+            try:
                os.remove(sourcePath)
-               logger.debug("Completed removing old file [%s]." % sourcePath)
-            except: 
+               logger.debug("Completed removing old file [%s].", sourcePath)
+            except:
                raise IOError("Failed to remove file [%s] after splitting it." % (sourcePath))
    finally:
       os.chdir(cwd)
