@@ -9,9 +9,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1099 2015-01-05 20:49:18Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +33,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2011,2013-2015"
-VERSION     = "2.24.2"
-DATE        = "05 Jan 2015"
-URL         = "http://cedar-backup.sourceforge.net/"
+VERSION     = "2.25.0"
+DATE        = "29 Jul 2015"
+URL         = "https://bitbucket.org/cedarsolutions/cedar-backup2"
 
