@@ -28,7 +28,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Cedar Backup, release 2
 # Purpose  : Provides general-purpose utilities.
 #
@@ -39,16 +39,16 @@
 ########################################################################
 
 """
-Provides general-purpose utilities. 
+Provides general-purpose utilities.
 
 @sort: AbsolutePathList, ObjectTypeList, RestrictedContentList, RegexMatchList,
-       RegexList, _Vertex, DirectedGraph, PathResolverSingleton, 
+       RegexList, _Vertex, DirectedGraph, PathResolverSingleton,
        sortDict, convertSize, getUidGid, changeOwnership, splitCommandLine,
        resolveCommand, executeCommand, calculateFileAge, encodePath, nullDevice,
-       deriveDayOfWeek, isStartOfWeek, buildNormalizedPath, 
-       ISO_SECTOR_SIZE, BYTES_PER_SECTOR, 
-       BYTES_PER_KBYTE, BYTES_PER_MBYTE, BYTES_PER_GBYTE, KBYTES_PER_MBYTE, MBYTES_PER_GBYTE, 
-       SECONDS_PER_MINUTE, MINUTES_PER_HOUR, HOURS_PER_DAY, SECONDS_PER_DAY, 
+       deriveDayOfWeek, isStartOfWeek, buildNormalizedPath,
+       ISO_SECTOR_SIZE, BYTES_PER_SECTOR,
+       BYTES_PER_KBYTE, BYTES_PER_MBYTE, BYTES_PER_GBYTE, KBYTES_PER_MBYTE, MBYTES_PER_GBYTE,
+       SECONDS_PER_MINUTE, MINUTES_PER_HOUR, HOURS_PER_DAY, SECONDS_PER_DAY,
        UNIT_BYTES, UNIT_KBYTES, UNIT_MBYTES, UNIT_GBYTES, UNIT_SECTORS
 
 @var ISO_SECTOR_SIZE: Size of an ISO image sector, in bytes.
@@ -90,9 +90,9 @@ from CedarBackup2.release import VERSION, DATE
 try:
    import pwd
    import grp
-   _UID_GID_AVAILABLE = True   
+   _UID_GID_AVAILABLE = True
 except ImportError:
-   _UID_GID_AVAILABLE = False   
+   _UID_GID_AVAILABLE = False
 
 
 ########################################################################
@@ -130,8 +130,8 @@ UMOUNT_COMMAND     = [ "umount", ]
 DEFAULT_LANGUAGE   = "C"
 LANG_VAR           = "LANG"
 LOCALE_VARS        = [ "LC_ADDRESS", "LC_ALL", "LC_COLLATE",
-                       "LC_CTYPE", "LC_IDENTIFICATION", 
-                       "LC_MEASUREMENT", "LC_MESSAGES", 
+                       "LC_CTYPE", "LC_IDENTIFICATION",
+                       "LC_MEASUREMENT", "LC_MESSAGES",
                        "LC_MONETARY", "LC_NAME", "LC_NUMERIC",
                        "LC_PAPER", "LC_TELEPHONE", "LC_TIME", ]
 
@@ -146,12 +146,12 @@ class UnorderedList(list):
    Class representing an "unordered list".
 
    An "unordered list" is a list in which only the contents matter, not the
-   order in which the contents appear in the list.  
-   
+   order in which the contents appear in the list.
+
    For instance, we might be keeping track of set of paths in a list, because
    it's convenient to have them in that form.  However, for comparison
    purposes, we would only care that the lists contain exactly the same
-   contents, regardless of order.  
+   contents, regardless of order.
 
    I have come up with two reasonable ways of doing this, plus a couple more
    that would work but would be a pain to implement.  My first method is to
@@ -267,7 +267,7 @@ class AbsolutePathList(UnorderedList):
    This is an unordered list.
 
    We override the C{append}, C{insert} and C{extend} methods to ensure that
-   any item added to the list is an absolute path.  
+   any item added to the list is an absolute path.
 
    Each item added to the list is encoded using L{encodePath}.  If we don't do
    this, we have problems trying certain operations between strings and unicode
@@ -324,7 +324,7 @@ class ObjectTypeList(UnorderedList):
    The C{objectName} value will be used in exceptions, i.e. C{"Item must be a
    CollectDir object."} if C{objectName} is C{"CollectDir"}.
    """
-   
+
    def __init__(self, objectType, objectName):
       """
       Initializes a typed list for a particular type.
@@ -389,7 +389,7 @@ class RestrictedContentList(UnorderedList):
    for instance lists and strings -- you will likely see AttributeError
    exceptions or other problems.
    """
-   
+
    def __init__(self, valuesList, valuesDescr, prefix=None):
       """
       Initializes a list restricted to containing certain values.
@@ -449,12 +449,12 @@ class RegexMatchList(UnorderedList):
    This is an unordered list.
 
    We override the C{append}, C{insert} and C{extend} methods to ensure that
-   any item added to the list matches the indicated regular expression.  
+   any item added to the list matches the indicated regular expression.
 
    @note: If you try to put values that are not strings into the list, you will
    likely get either TypeError or AttributeError exceptions as a result.
    """
-   
+
    def __init__(self, valuesRegex, emptyAllowed=True, prefix=None):
       """
       Initializes a list restricted to containing certain values.
@@ -588,13 +588,13 @@ class DirectedGraph(object):
 
    A graph B{G=(V,E)} consists of a set of vertices B{V} together with a set
    B{E} of vertex pairs or edges.  In a directed graph, each edge also has an
-   associated direction (from vertext B{v1} to vertex B{v2}).  A C{DirectedGraph} 
+   associated direction (from vertext B{v1} to vertex B{v2}).  A C{DirectedGraph}
    object provides a way to construct a directed graph and execute a depth-
    first search.
 
    This data structure was designed based on the graphing chapter in
    U{The Algorithm Design Manual<http://www2.toki.or.id/book/AlgDesignManual/>},
-   by Steven S. Skiena.  
+   by Steven S. Skiena.
 
    This class is intended to be used by Cedar Backup for dependency ordering.
    Because of this, it's not quite general-purpose.  Unlike a "general" graph,
@@ -697,9 +697,9 @@ class DirectedGraph(object):
       A directed acyclic graph (or "DAG") is a directed graph with no directed
       cycles.  A topological sort of a DAG is an ordering on the vertices such
       that all edges go from left to right.  Only an acyclic graph can have a
-      topological sort, but any DAG has at least one topological sort.  
+      topological sort, but any DAG has at least one topological sort.
 
-      Since a topological sort only makes sense for an acyclic graph, this 
+      Since a topological sort only makes sense for an acyclic graph, this
       method throws an exception if a cycle is found.
 
       A depth-first search only makes sense if the graph is acyclic.  If the
@@ -738,7 +738,7 @@ class DirectedGraph(object):
          elif endpoint.state != self._EXPLORED:
             raise ValueError("Cycle found in graph (found '%s' while searching '%s')." % (vertex.name, endpoint.name))
       if vertex.name is not None:
-         ordering.insert(0, vertex.name) 
+         ordering.insert(0, vertex.name)
       vertex.state = self._EXPLORED
 
 
@@ -766,7 +766,7 @@ class PathResolverSingleton(object):
    seem like kind of a "big hammer" solution.  Besides that, it might also
    represent a security flaw (for instance, I prefer not to mess with root's
    C{$PATH} on the application level if I don't have to).
-   
+
    The alternative is to set up some sort of configuration for the path to
    certain executables, i.e. "find C{svnlook} in C{/usr/local/bin/svnlook}" or
    whatever.  This PathResolverSingleton aims to provide a good solution to the
@@ -777,7 +777,7 @@ class PathResolverSingleton(object):
    This way, with no real effort on the part of the caller, behavior can neatly
    degrade to something equivalent to the current behavior if there is no
    special mapping or if the singleton was never initialized in the first
-   place.  
+   place.
 
    Even better, extensions automagically get access to the same resolver
    functionality, and they don't even need to understand how the mapping
@@ -797,7 +797,7 @@ class PathResolverSingleton(object):
 
    _instance = None     # Holds a reference to singleton instance
 
-   class _Helper:
+   class _Helper(object):
       """Helper class to provide a singleton factory method."""
       def __init__(self):
          pass
@@ -807,7 +807,7 @@ class PathResolverSingleton(object):
             obj = PathResolverSingleton()
             PathResolverSingleton._instance = obj
          return PathResolverSingleton._instance
-    
+
    getInstance = _Helper()    # Method that callers will use to get an instance
 
    def __init__(self):
@@ -827,7 +827,7 @@ class PathResolverSingleton(object):
       value = default
       if name in self._mapping.keys():
          value = self._mapping[name]
-      logger.debug("Resolved command [%s] to [%s]." % (name, value))
+      logger.debug("Resolved command [%s] to [%s].", name, value)
       return value
 
    def fill(self, mapping):
@@ -839,7 +839,7 @@ class PathResolverSingleton(object):
       self._mapping = { }
       for key in mapping.keys():
          self._mapping[key] = mapping[key]
-      
+
 
 ########################################################################
 # Pipe class definition
@@ -853,13 +853,13 @@ class Pipe(Popen):
    with a pipe.  First, C{executeCommand} only reads from the pipe, and
    never writes to it.  Second, C{executeCommand} needs a way to discard all
    output written to C{stderr}, as a means of simulating the shell
-   C{2>/dev/null} construct.  
+   C{2>/dev/null} construct.
    """
    def __init__(self, cmd, bufsize=-1, ignoreStderr=False):
       stderr = STDOUT
       if ignoreStderr:
          devnull = nullDevice()
-         stderr = os.open(devnull, os.O_RDWR) 
+         stderr = os.open(devnull, os.O_RDWR)
       Popen.__init__(self, shell=False, args=cmd, bufsize=bufsize, stdin=None, stdout=PIPE, stderr=stderr)
 
 
@@ -1010,7 +1010,7 @@ class Diagnostics(object):
          return locale.getdefaultlocale()[0]
       except:
          return "(unknown)"
-   
+
    def _getTimestamp(self):
       """
       Property target to get a current date/time stamp.
@@ -1059,7 +1059,7 @@ def sortDict(d):
 def removeKeys(d, keys):
    """
    Removes all of the keys from the dictionary.
-   The dictionary is altered in-place. 
+   The dictionary is altered in-place.
    Each key must exist in the dictionary.
    @param d: Dictionary to operate on
    @param keys: List of keys to remove
@@ -1090,7 +1090,7 @@ def convertSize(size, fromUnit, toUnit):
       - C{UNIT_SECTORS} - Sectors, where 1 sector = 2048 B
 
    @param size: Size to convert
-   @type size: Integer or float value in units of C{fromUnit} 
+   @type size: Integer or float value in units of C{fromUnit}
 
    @param fromUnit: Unit to convert from
    @type fromUnit: One of the units listed above
@@ -1162,7 +1162,7 @@ def displayBytes(bytes, digits=2): # pylint: disable=W0622
 
    @return: String, formatted for sensible display.
    """
-   if(bytes is None):
+   if bytes is None:
       raise ValueError("Cannot display byte value of None.")
    bytes = float(bytes)
    if math.fabs(bytes) < BYTES_PER_KBYTE:
@@ -1191,14 +1191,14 @@ def getFunctionReference(module, function):
    This does some hokey-pokey to get back a reference to a dynamically named
    function.  For instance, say you wanted to get a reference to the
    C{os.path.isdir} function.  You could use::
-   
+
       myfunc = getFunctionReference("os.path", "isdir")
 
    Although we won't bomb out directly, behavior is pretty much undefined if
    you pass in C{None} or C{""} for either C{module} or C{function}.
 
    The only validation we enforce is that whatever we get back must be
-   callable.  
+   callable.
 
    I derived this code based on the internals of the Python unittest
    implementation.  I don't claim to completely understand how it works.
@@ -1211,7 +1211,7 @@ def getFunctionReference(module, function):
 
    @return: Reference to function associated with name.
 
-   @raise ImportError: If the function cannot be found. 
+   @raise ImportError: If the function cannot be found.
    @raise ValueError: If the resulting reference is not callable.
 
    @copyright: Some of this code, prior to customization, was originally part
@@ -1234,7 +1234,7 @@ def getFunctionReference(module, function):
       parts = parts[1:]
    obj = module
    for part in parts:
-      obj = getattr(obj, part) 
+      obj = getattr(obj, part)
    if not callable(obj):
       raise ValueError("Reference to %s.%s is not callable." % (module, function))
    return obj
@@ -1265,7 +1265,7 @@ def getUidGid(user, group):
          gid = grp.getgrnam(group)[2]
          return (uid, gid)
       except Exception, e:
-         logger.debug("Error looking up uid and gid for [%s:%s]: %s" % (user, group, e))
+         logger.debug("Error looking up uid and gid for [%s:%s]: %s", user, group, e)
          raise ValueError("Unable to lookup up uid and gid for passed in user/group.")
    else:
       return (0, 0)
@@ -1289,15 +1289,15 @@ def changeOwnership(path, user, group):
    """
    if _UID_GID_AVAILABLE:
       if user is None or group is None:
-         logger.debug("User or group is None, so not attempting to change owner on [%s]." % path)
+         logger.debug("User or group is None, so not attempting to change owner on [%s].", path)
       elif not isRunningAsRoot():
-         logger.debug("Not root, so not attempting to change owner on [%s]." % path)
+         logger.debug("Not root, so not attempting to change owner on [%s].", path)
       else:
          try:
             (uid, gid) = getUidGid(user, group)
             os.chown(path, uid, gid)
          except Exception, e:
-            logger.error("Error changing ownership of [%s]: %s" % (path, e))
+            logger.error("Error changing ownership of [%s]: %s", path, e)
 
 
 #############################
@@ -1339,7 +1339,7 @@ def splitCommandLine(commandLine):
    if commandLine is None:
       raise ValueError("Cannot split command line of None.")
    fields = re.findall('[^ "]+|"[^"]+"', commandLine)
-   fields = map(lambda field: field.replace('"', ''), fields)
+   fields = [field.replace('"', '') for field in fields]
    return fields
 
 
@@ -1354,7 +1354,7 @@ def resolveCommand(command):
    Both extensions and standard Cedar Backup functionality need a way to
    resolve the "real" location of various executables.  Normally, they assume
    that these executables are on the system path, but some callers need to
-   specify an alternate location.  
+   specify an alternate location.
 
    Ideally, we want to handle this configuration in a central location.  The
    Cedar Backup path resolver mechanism (a singleton called
@@ -1362,7 +1362,7 @@ def resolveCommand(command):
    mappings.  This function wraps access to the singleton, and is what all
    functions (extensions or standard functionality) should call if they need to
    find a command.
-   
+
    The passed-in command must actually be a list, in the standard form used by
    all existing Cedar Backup code (something like C{["svnlook", ]}).  The
    lookup will actually be done on the first element in the list, and the
@@ -1413,7 +1413,7 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
 
    By default, C{stdout} and C{stderr} will be intermingled in the output.
    However, if you pass in C{ignoreStderr=True}, then only C{stdout} will be
-   included in the output.  
+   included in the output.
 
    The C{doNotLog} parameter exists so that callers can force the function to
    not log command output to the debug log.  Normally, you would want to log.
@@ -1463,8 +1463,8 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
 
    @return: Tuple of C{(result, output)} as described above.
    """
-   logger.debug("Executing command %s with args %s." % (command, args))
-   outputLogger.info("Executing command %s with args %s." % (command, args))
+   logger.debug("Executing command %s with args %s.", command, args)
+   outputLogger.info("Executing command %s with args %s.", command, args)
    if doNotLog:
       logger.debug("Note: output will not be logged, per the doNotLog flag.")
       outputLogger.info("Note: output will not be logged, per the doNotLog flag.")
@@ -1486,7 +1486,7 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
          if returnOutput: output.append(line)
          if outputFile is not None: outputFile.write(line)
          if not doNotLog: outputLogger.info(line[:-1])  # this way the log will (hopefully) get updated in realtime
-      if outputFile is not None: 
+      if outputFile is not None:
          try: # note, not every file-like object can be flushed
             outputFile.flush()
          except: pass
@@ -1531,7 +1531,7 @@ def calculateFileAge(path):
    """
    currentTime = int(time.time())
    fileStats = os.stat(path)
-   lastUse = max(fileStats.st_atime, fileStats.st_mtime)  # "most recent" is "largest" 
+   lastUse = max(fileStats.st_atime, fileStats.st_mtime)  # "most recent" is "largest"
    ageInSeconds = currentTime - lastUse
    ageInDays = ageInSeconds / SECONDS_PER_DAY
    return ageInDays
@@ -1608,26 +1608,26 @@ def unmount(mountPoint, removeAfter=False, attempts=1, waitSeconds=0):
    """
    if os.path.ismount(mountPoint):
       for attempt in range(0, attempts):
-         logger.debug("Making attempt %d to unmount [%s]." % (attempt, mountPoint))
+         logger.debug("Making attempt %d to unmount [%s].", attempt, mountPoint)
          command = resolveCommand(UMOUNT_COMMAND)
          result = executeCommand(command, [ mountPoint, ], returnOutput=False, ignoreStderr=True)[0]
          if result != 0:
-            logger.error("Error [%d] unmounting [%s] on attempt %d." % (result, mountPoint, attempt))
+            logger.error("Error [%d] unmounting [%s] on attempt %d.", result, mountPoint, attempt)
          elif os.path.ismount(mountPoint):
-            logger.error("After attempt %d, [%s] is still mounted." % (attempt, mountPoint))
+            logger.error("After attempt %d, [%s] is still mounted.", attempt, mountPoint)
          else:
-            logger.debug("Successfully unmounted [%s] on attempt %d." % (mountPoint, attempt))
+            logger.debug("Successfully unmounted [%s] on attempt %d.", mountPoint, attempt)
             break  # this will cause us to skip the loop else: clause
          if attempt+1 < attempts:  # i.e. this isn't the last attempt
             if waitSeconds > 0:
-               logger.info("Sleeping %d second(s) before next unmount attempt." % waitSeconds)
+               logger.info("Sleeping %d second(s) before next unmount attempt.", waitSeconds)
                time.sleep(waitSeconds)
       else:
          if os.path.ismount(mountPoint):
             raise IOError("Unable to unmount [%s] after %d attempts." % (mountPoint, attempts))
-         logger.info("Mount point [%s] seems to have finally gone away." % mountPoint)
+         logger.info("Mount point [%s] seems to have finally gone away.", mountPoint)
       if os.path.isdir(mountPoint) and removeAfter:
-         logger.debug("Removing mount point [%s]." % mountPoint)
+         logger.debug("Removing mount point [%s].", mountPoint)
          os.rmdir(mountPoint)
 
 
@@ -1657,7 +1657,7 @@ def deviceMounted(devicePath):
       for line in lines:
          (mountDevice, mountPoint, remainder) = line.split(None, 2)
          if mountDevice in [ devicePath, realPath, ]:
-            logger.debug("Device [%s] is mounted at [%s]." % (devicePath, mountPoint))
+            logger.debug("Device [%s] is mounted at [%s].", devicePath, mountPoint)
             return True
    return False
 
@@ -1715,7 +1715,7 @@ def encodePath(path):
 
       So we have three options:
 
-      1. Skip this string, only return the ones that can be converted to Unicode. 
+      1. Skip this string, only return the ones that can be converted to Unicode.
          Give the user the impression the file does not exist.
       2. Return the string as a byte string
       3. Refuse to listdir altogether, raising an exception (i.e. return nothing)
@@ -1852,7 +1852,7 @@ def buildNormalizedPath(path):
    name.  To make a valid file name out of a complete path, we have to convert
    or remove some characters that are significant to the filesystem -- in
    particular, the path separator and any leading C{'.'} character (which would
-   cause the file to be hidden in a file listing).  
+   cause the file to be hidden in a file listing).
 
    Note that this is a one-way transformation -- you can't safely derive the
    original path from the normalized path.
@@ -1896,9 +1896,9 @@ def buildNormalizedPath(path):
 def sanitizeEnvironment():
    """
    Sanitizes the operating system environment.
-   
+
    The operating system environment is contained in C{os.environ}.  This method
-   sanitizes the contents of that dictionary.  
+   sanitizes the contents of that dictionary.
 
    Currently, all it does is reset the locale (removing C{$LC_*}) and set the
    default language (C{$LANG}) to L{DEFAULT_LANGUAGE}.  This way, we can count
@@ -1918,7 +1918,7 @@ def sanitizeEnvironment():
       if os.environ[LANG_VAR] != DEFAULT_LANGUAGE: # no need to reset if it exists (avoid leaks on BSD systems)
          os.environ[LANG_VAR] = DEFAULT_LANGUAGE
    return os.environ.copy()
-   
+
 
 #############################
 # dereferenceLink() function
